<?php

/**
 * @file
 * Define pages for Forum Grade Center Forum Summary
 */

/**
 * Called by hook theme to display a table like display of information presented
 */

function theme_class_participation_fake_table($variables) {
  drupal_add_css(drupal_get_path('module', 'class_participation') . '/stylesheets/fake-table-sass.css');
  drupal_add_js(drupal_get_path('module', 'class_participation') . '/js/class_participation-fake-table.js', array('scope' => 'footer'));
  $fake_table_name = $variables['fake_table_name'];
  $header = $variables['header'];
  $rows = $variables['rows'];
  $attributes = $variables['attributes'];
  $sticky = $variables['sticky'];
  $expand_collapse = $variables['expand_collapse'];

  $expand_icon = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" id="Layer_1" x="0px" y="0px" width="20px" height="20px" viewBox="0 0 20 20" enable-background="new 0 0 20 20" xml:space="preserve">
<line class ="vert-line" fill="none" stroke="#fff" stroke-width="3" x1="10" y1="14.2" x2="10" y2="5.8"/>
<circle fill="none" stroke="#fff" stroke-width="2" cx="10" cy="10" r="8.5"/>
<line class ="horiz-line" fill="none" stroke="#fff" stroke-width="3" x1="5.7" y1="10" x2="14.2" y2="10"/>
</svg>';

  // Wrap theme elements for easier jQuery selection
  $output = "<div class='fake-table-wrapper no-print'>";
  // Add fake table header with title
  if (count($fake_table_name)) {
    if (!is_null($expand_collapse)) {
      $output .= '<div class= "fake-table-name expand-collapse">' . $fake_table_name . '</div>';
      $output .= '<div class="fake-table-expand-collapse-wrapper">';
      if ($expand_collapse == 'expanded') {
        $output .=   '<span class="fake-table-expand-collapse collapse">' . $expand_icon . '</span>';
      } else {
        $output .=   '<span class="fake-table-expand-collapse">' . $expand_icon . '</span>';
      }

      $output .= '</div><!-- .fake-table-expand-collapse -->';
    } else {
      $output .= '<div class= "fake-table-name">' . $fake_table_name . '</div>';
    }

  }
  // Add sticky headers, if applicable.
  if (count($header) && $sticky) {
    drupal_add_js('misc/tableheader.js');
    // Add 'sticky-enabled' class to the table to identify it for JS.
    // This is needed to target tables constructed by this function.
    $attributes['class'][] = 'sticky-enabled';
  }
  $attributes['class'][] = 'fake-table';
  if ($expand_collapse == 'collapsed') {
    $attributes['class'][] = 'collapsed';
  }

  $output .= '<div' . drupal_attributes($attributes) . ">\n";

  // Format the fake table header:
  if (count($header)) {
    $output .= (count($rows) ? ' <div class="fake-thead has-rows">' : ' <dive class"fake-thead no-rows">');
    if (is_array($header)) {
      foreach ($header as $cell) {
//      $cell = tablesort_header($cell, $header, $ts);
        $output .= _theme_class_participation_forum_topic_cell($cell, TRUE);
      }
    } else {
      $output .= $header;
    }
    // Using ternary operator to close the tags based on whether or not there are rows
    $output .= "</div><!-- .fake-thead -->\n";
  }


  // Format the fake table rows:
  if (count($rows)) {

    $flip = array(
      'even' => 'odd',
      'odd' => 'even',
    );
    $class = 'even';
    $cell_count = 0;
    foreach ($rows as $number => $row) {
      // special cases handling thanks to php.net/strops
      $header_row_class = FALSE; // most rows aren't headers
      $subhead_row_class = FALSE; // most rows aren't subheaders either
      $cell_row_class = FALSE; // most rows don't have just 1 cell
      $class_string = $row[0]['class'];
      $header_row_class_string = "header-row";
      $subhead_row_class_string = "subhead-row";
      $cell_row_class_string = "cell-row";
      $header_row_pos = strpos($class_string, $header_row_class_string);
      $subhead_row_pos = strpos($class_string, $subhead_row_class_string);
      $cell_row_pos = strpos($class_string, $cell_row_class_string);

      if ($header_row_pos != FALSE) {
        $header_row_class = TRUE;
      }
      if ($subhead_row_pos != FALSE) {
        $subhead_row_class = TRUE;
      }
      if ($cell_row_pos != FALSE) {
        $cell_row_class = TRUE;
      }
      // Check if we're dealing with a simple or complex row
      if (isset($row['data'])) {
        $cells = $row['data'];
        $no_striping = isset($row['no_striping']) ? $row['no_striping'] : FALSE;
        // Set the attributes array and exclude 'data' and 'no_striping'.
        $attributes = $row;
        unset($attributes['data']);
        unset($attributes['no_striping']);
      }
      else {
        $cells = $row;
        $attributes = array();
        $no_striping = FALSE;
      }

      if (count($cells)) {
        // Add odd/even class
        if (!$no_striping) {
          $class = $flip[$class];
          $attributes['class'][] = $class . ' fake-row-wrapper cell-count-' . $cell_count;
        } else {
          $attributes['class'][] = 'fake-row-wrapper cell-count-' . $cell_count;
        }
        if ($header_row_class == TRUE) {
          $attributes['class'][] = $header_row_class_string;
          // reset
          $header_row_class == FALSE;
        }
        if ($subhead_row_class == TRUE) {
          $attributes['class'][] = $subhead_row_class_string;
          // reset
          $subhead_row_class == FALSE;
        }
        if ($cell_row_class == TRUE) {
          $attributes['class'][] = $cell_row_class_string;
          // reset
          $cell_row_class == FALSE;
        }

        // Build row
        $output .= ' <div' . drupal_attributes($attributes) . ' class="fake-row">';
        $i = 0;
        foreach ($cells as $cell) {
//          $cell = tablesort_cell($cell, $header, $ts, $i++);
          $output .= _theme_class_participation_forum_topic_cell($cell);
        }
        $output .= " </div><!-- .fake-row -->\n";
      }
      $cell_count++;
    }

  }

  $output .= "</div><!-- .fake-table -->\n";
  $output .= "</div><!-- .fake-table-wrapper-->\n";
  return $output;
}


function _theme_class_participation_forum_topic_cell($cell, $header = FALSE) {
  if (is_array($cell)) {
    $data = isset($cell['data']) ? $cell['data'] : '';
    // Cell's data property can be a string or a renderable array.
    if (is_array($data)) {
      $data = drupal_render($data);
    }
    $header |= isset($cell['header']);
    unset($cell['data']);
    unset($cell['header']);
    $attributes = drupal_attributes($cell);
  }
  else {
    $data = $cell;
  }

  if ($header) {
    $output = "<div$attributes>$data</div>";
  }
  else {
    $output = "<div$attributes>$data</div>";
  }

  return $output;
}
